import sys

from onep.onep import main

main(sys.argv)
